@@ -205,7 +205,7 @@ sub canonicalize_args{ # DEPRECATED
 
     Carp::cluck("$self->canonicalize_args has been deprecated."
         . "Use \$self->_process_options instead.")
-            if _MOUSE_VERBOSE;
+            if Mouse::Util::_MOUSE_VERBOSE;
 
     return %args;
 }
@@ -215,7 +215,7 @@ sub create { # DEPRECATED
 
     Carp::cluck("$self->create has been deprecated."
         . "Use \$meta->add_attribute and \$attr->install_accessors instead.")
-            if _MOUSE_VERBOSE;
+            if Mouse::Util::_MOUSE_VERBOSE;
 
     # noop
     return $self;
@@ -284,7 +284,7 @@ sub clone_parent { # DEPRECATED
 
     Carp::cluck("$self->clone_parent has been deprecated."
         . "Use \$meta->add_attribute and \$attr->install_accessors instead.")
-        if _MOUSE_VERBOSE;
+        if Mouse::Util::_MOUSE_VERBOSE;
 
     $self->clone_and_inherited_args($class, $name, %args);
 }
@@ -360,7 +360,7 @@ sub _canonicalize_handles {
 
         my $meta = Mouse::Meta::Class->initialize("$class_or_role"); # "" for stringify
         return map  { $_ => $_ }
-               grep { $_ ne 'meta' && !Mouse::Object->can($_) && $_ =~ $handles }
+               grep { !Mouse::Object->can($_) && $_ =~ $handles }
                    Mouse::Util::is_a_metarole($meta)
                         ? $meta->get_method_list
                         : $meta->get_all_method_names;
@@ -435,7 +435,7 @@ Mouse::Meta::Attribute - The Mouse attribute metaclass
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_06
+This document describes Mouse version 0.40_07
 
 =head1 METHODS
 
