@@ -6,7 +6,8 @@ use Scalar::Util ();
 
 my %METAS;
 
-if(Mouse::Util::_MOUSE_XS){
+# XXX: work around a warning "useless use of a constant in void context" in 5.6.2
+if(&Mouse::Util::_MOUSE_XS()){
     # register meta storage for performance
     Mouse::Util::__register_metaclass_storage(\%METAS, 0);
 
@@ -29,7 +30,19 @@ sub initialize {
         ||= $class->_construct_meta(package => $package_name, @args);
 }
 
-sub class_of{
+sub reinitialize {
+    my($class, $package_name, @args) = @_;
+
+    $package_name = $package_name->name if ref $package_name;
+
+    ($package_name && !ref($package_name))
+        || $class->throw_error("You must pass a package name and it cannot be blessed");
+
+    delete $METAS{$package_name};
+    return $class->initialize($package_name, @args);
+}
+
+sub _class_of{
     my($class_or_instance) = @_;
     return undef unless defined $class_or_instance;
     return $METAS{ ref($class_or_instance) || $class_or_instance };
@@ -37,14 +50,14 @@ sub class_of{
 
 # Means of accessing all the metaclasses that have
 # been initialized thus far
-#sub get_all_metaclasses         {        %METAS         }
-sub get_all_metaclass_instances { values %METAS         }
-sub get_all_metaclass_names     { keys   %METAS         }
-sub get_metaclass_by_name       { $METAS{$_[0]}         }
-#sub store_metaclass_by_name     { $METAS{$_[0]} = $_[1] }
-#sub weaken_metaclass            { weaken($METAS{$_[0]}) }
-#sub does_metaclass_exist        { defined $METAS{$_[0]} }
-#sub remove_metaclass_by_name    { delete $METAS{$_[0]}  }
+#sub _get_all_metaclasses         {        %METAS         }
+sub _get_all_metaclass_instances { values %METAS         }
+sub _get_all_metaclass_names     { keys   %METAS         }
+sub _get_metaclass_by_name       { $METAS{$_[0]}         }
+#sub _store_metaclass_by_name     { $METAS{$_[0]} = $_[1] }
+#sub _weaken_metaclass            { weaken($METAS{$_[0]}) }
+#sub _does_metaclass_exist        { defined $METAS{$_[0]} }
+#sub _remove_metaclass_by_name    { delete $METAS{$_[0]}  }
 
 sub name;
 
@@ -298,7 +311,7 @@ Mouse::Meta::Module - The base class for Mouse::Meta::Class and Mouse::Meta::Rol
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_06
+This document describes Mouse version 0.40_07
 
 =head1 SEE ALSO
 
